Crate monument_cli
source ·Expand description
Crate for loading and running Monument’s input files. The CLI itself is a very thin wrapper
around monument_toml, parsing CLI args and immediately calling into this. This crate is also
shared between the various integration test runners, making sure that the integration tests run
in exactly the same way as Monument itself.
Modules
Code for handling the logging of compositions or updates provided by Monument
Structs
Enums
What item should be debug printed
How this instance of Monument is being run