Struct monument_cli::spec::Spec
source · pub struct Spec { /* private fields */ }Expand description
The specification for a set of compositions which Monument should search. The Spec type is
parsed directly from the TOML, and can be thought of as an AST representation of the TOML
file. Like ASTs, this specifies a superset of valid programs - so building a composition
search can also fail (as can lowering an AST).
Implementations