Module monument_cli::toml_file

source ·

Structs

  • Common values for all method variants
  • The specification for a set of compositions which Monument should search. The TomlFile type is parsed directly from the TOML, and can be thought of as an AST representation of the TOML file. Like ASTs, this specifies a superset of valid programs - so building a composition search can also fail (as can lowering an AST).

Enums