TomlFile

Struct TomlFile 

pub struct TomlFile { /* private fields */ }
The specification for a set of compositions which Monument should search. The TomlFile type is parsed directly from the TOML, and can be thought of as an AST representation of the TOML file. Like ASTs, this specifies a superset of valid programs - so building a composition search can also fail (as can lowering an AST).

Implementations

Source

impl TomlFile

pub fn new(toml_path: &Path) -> Result<Self>

Load and parse a TomlFile structure from a TOML file

pub fn to_params( &self, toml_path: &Path, ) -> Result<(Parameters, Vec<MusicDisplay>)>

Build a set of Parameters from this TomlFile

pub fn should_print_atw(&self) -> bool

pub fn config(&self, opts: &Options, leak_search_memory: bool) -> Config