Crate for loading and running Monument’s input files. The CLI itself is a very thin wrapper around monument_toml, parsing CLI args and immediately calling into this. This crate is also shared between the various integration test runners, making sure that the integration tests run in exactly the same way as Monument itself.

Modules

Structs

Enums

What item should be debug printed
How this instance of Monument is being run
The Source of the TOML that Monument should read. In nearly all cases, this will be loaded from the file a given Path. For the test runner it’s useful to be able to run Monument on strings that aren’t loaded from a specific file, so for this we have the Str variant.

Functions