Struct monument_cli::args::Options
source · pub struct Options {
pub num_threads: Option<usize>,
pub graph_size_limit: Option<usize>,
pub mem_limit: Option<usize>,
pub debug_option: Option<DebugOption>,
}Fields
num_threads: Option<usize>The maximum number of threads that Monument will use.
graph_size_limit: Option<usize>The maximum number of chunks in the chunk graph. Exceeding this during generation will cause an error. Defaults to 100K.
mem_limit: Option<usize>The maximum number of bytes of heap memory that Monument’s search routine can allocate. Defaults to 80% of what’s available.
debug_option: Option<DebugOption>Debug options. spec, query, layout and graph print the corresponding data
structures. no-search will run as normal but stop just before starting the full search.