Module monument_cli::spec
source · Structs
Common values for all method variants
The specification for a set of compositions which Monument should search. The
Spec type is
parsed directly from the TOML, and can be thought of as an AST representation of the TOML
file. Like ASTs, this specifies a superset of valid programs - so building a composition
search can also fail (as can lowering an AST).Enums
The contents of the
[method] header in the input TOML fileThe different styles of spliced that can be generated.