Module monument_cli::spec
source · [−]Structs
Common values for all method variants
Values common to all enum variants of MusicSpec
The specification for a music file
The specification for a set of compositions which Monument should search. The Spec type is
parsed directly from the TOML, and can be thought of as an AST representation of the TOML
file. Like ASTs, this specifies a superset of valid programs - so building a composition
search can also fail (as can lowering an AST).
Enums
The contents of the [method] header in the input TOML file
The specification for one type of music
A version of OptRange which allows for convenient deserialisation from a single number
(e.g. count = 5 is equivalent to count = { min = 5, max = 5 })