Structs

Common values for methods

Values common to all enum variants of MusicSpec

The specification for a music file

The specification for a set of compositions which Monument should search. The Spec type is parsed directly from the TOML, and can be thought of as an AST representation of the TOML file. Like ASTs, this specifies a superset of valid programs - so building a composition search can also fail (as can lowering an AST).

Enums

The contents of the [method] header in the input TOML file

The specification for one type of music

Error generated when a user tries to read a TOML file from the FS

Functions