Module monument_cli::toml_file
source · Structs
- Common values for all method variants
- The specification for a set of compositions which Monument should search. The
TomlFiletype is parsed directly from theTOML, and can be thought of as an AST representation of the TOML file. Like ASTs, this specifies a superset of valid programs - so building a composition search can also fail (as can lowering an AST).
Enums
- The different styles of spliced that can be generated.
- The contents of the
[method]header in the input TOML file